@@ -1,5 +1,5 @@
 # Verilog::Getopt.pm -- Verilog command line parsing
-# $Id: Getopt.pm 4374 2005-08-03 15:35:42Z wsnyder $
+# $Id: Getopt.pm 5867 2005-09-06 20:30:00Z wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -29,7 +29,7 @@ use Cwd;
 ######################################################################
 #### Configuration Section
 
-$VERSION = '2.321';
+$VERSION = '2.330';
 
 # Basenames we should ignore when recursing directories,
 # Because they contain large files of no relevance
@@ -250,12 +250,13 @@ sub depend_files {
 
 sub get_parameters {
     my $self = shift;
+    my %args = (gcc_stlyle => $self->{gcc_style},);
     # Defines
     my @params = ();
     foreach my $def (sort (keys %{$self->{defines}})) {
 	my $defvalue = $self->defvalue($def);
 	$defvalue = "=".($defvalue||"") if (defined $defvalue && $defvalue ne "");
-	if ($self->{gcc_style}) {
+	if ($args{gcc_style}) {
 	    push @params, "-D${def}${defvalue}";
 	} else {
 	    push @params, "+define+${def}${defvalue}";
@@ -270,7 +271,7 @@ sub get_parameters {
     push @params, $exts if $exts;
     # Includes...
     foreach my $dir ($self->incdir()) {
-	if ($self->{gcc_style}) {
+	if ($args{gcc_style}) {
 	    push @params, "-I${dir}";
 	} else {
 	    push @params, "+incdir+${dir}";
